Fix assertion failure in PTH when tokens followed a closing #endif.
 - Ted, please check.

 - Missing test case because PTH won't reliably cache the tokens in a
   test case. *cough*


git-svn-id: https://llvm.org/svn/llvm-project/cfe/trunk@68966 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/Lex/PPDirectives.cpp b/lib/Lex/PPDirectives.cpp
index 52f673c..24b9432 100644
--- a/lib/Lex/PPDirectives.cpp
+++ b/lib/Lex/PPDirectives.cpp
@@ -351,10 +351,9 @@
       if (!CondInfo.FoundNonSkip) {
         CondInfo.FoundNonSkip = true;
         
         // Consume the eom token.
         CurPTHLexer->ParsingPreprocessorDirective = true;
-        LexUnexpandedToken(Tok);
-        assert(Tok.is(tok::eom));
+        DiscardUntilEndOfDirective();
         CurPTHLexer->ParsingPreprocessorDirective = false;
         
         break;
@@ -351,10 +351,9 @@
         CondInfo.FoundNonSkip = true;
         
-        // Consume the eom token.
+        // Scan until the eom token.
         CurPTHLexer->ParsingPreprocessorDirective = true;